%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%%                       LaTeX DOCUMENT CLASS                         %%%
%%%                  for preparing PWNT publications		       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\typeout{Document Style `pwnt_en' <2014>.}

\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{pwnt_en}[2014/10/13 Class for preparing PWNT publications (english version)]
\usepackage{ifthen}

\newboolean{@hrvdstyle} 
\newboolean{@bookstyle}
\newboolean{@procstyle}
\setboolean{@hrvdstyle}{false}
\setboolean{@bookstyle}{false}
\setboolean{@procstyle}{false}

\DeclareOption{hrvd}{%
  \setboolean{@hrvdstyle}{true}
}
\DeclareOption{book}{%
  \setboolean{@bookstyle}{true}
}
\DeclareOption{proc}{%
  \setboolean{@procstyle}{true}
  \setboolean{@hrvdstyle}{false}
  \setboolean{@bookstyle}{false}
}

\DeclareOption*{%
  \ClassWarning{pwnt_en}{Unknown option `\CurrentOption'}%
}
\ProcessOptions

\ifthenelse{\boolean{@procstyle}}
{%
  \LoadClass[twoside,onecolumn,a4paper,12pt]{article}
}
{%
  \LoadClass[twoside,onecolumn,a4paper,12pt]{book}
}

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{times}
\RequirePackage[flushmargin]{footmisc}


\ifthenelse{\boolean{@procstyle}}
{%
}
{%
\ifthenelse{\boolean{@hrvdstyle}}
{%
  \RequirePackage[hidelinks,draft=false]{hyperref}
  \RequirePackage[dcucite,abbr]{harvard}
  \renewcommand{\harvardand}{\&}  
}
{}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% FOOTNOTES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FOOTNOTES INDENT
\newlength{\myFootnoteWidth}
\newlength{\myFootnoteLabel}
\setlength{\myFootnoteLabel}{7pt}%  <-- can be changed to any valid value
\renewcommand{\@makefntext}[1]{%
  \setlength{\myFootnoteWidth}{\columnwidth}%
  \addtolength{\myFootnoteWidth}{-\myFootnoteLabel}%
  \noindent\makebox[\myFootnoteLabel][r]{\@makefnmark\ }%
  \parbox[t]{\myFootnoteWidth}{#1}%
}

% FOOTNOTE WITHOUT A SYMBOL
\newcommand{\blfootnote}{\xdef\@thefnmark{}\@footnotetext}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PAGE LAYOUT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% paper size A4
\setlength{\paperheight}{297mm}
\setlength{\paperwidth}{210mm}

% head and foot
\setlength{\topmargin}{0mm}
\addtolength{\topmargin}{-1in}
\newlength{\realtopmargin}
\setlength{\realtopmargin}{5mm}
\addtolength{\topmargin}{\realtopmargin}
\setlength{\headheight}{19mm}
\setlength{\headsep}{5mm}
\setlength{\topskip}{0mm}
\setlength{\footskip}{22.0mm}

% margins
\newlength{\realoddsidemargin}
\setlength{\realoddsidemargin}{20mm}
\addtolength{\realoddsidemargin}{5mm}   % 0.5cm more on odd pages
\newlength{\realevensidemargin}
\setlength\realevensidemargin{20mm}

\setlength{\oddsidemargin}{0mm}
\addtolength{\oddsidemargin}{-1in}
\addtolength{\oddsidemargin}{\realoddsidemargin}
\setlength{\evensidemargin}{0mm}
\addtolength{\evensidemargin}{-1in}
\addtolength{\evensidemargin}{\realevensidemargin}

% text height and width
\setlength{\textheight}{\paperheight}
\addtolength{\textheight}{-\realtopmargin}
\addtolength{\textheight}{-\headheight}
\addtolength{\textheight}{-\headsep}
\addtolength{\textheight}{-\footskip}
%\addtolength{\textheight}{1.0in}
\setlength{\textwidth}{\paperwidth}
\addtolength{\textwidth}{-\realoddsidemargin}    % because oddsidemargin is < 0
\addtolength{\textwidth}{-\realevensidemargin}   % because evensidemargin is < 0

% title part width
\newlength{\titlewidth}
\setlength\titlewidth{\textwidth}

% chapter over and underline length
\newlength{\chapterline}
\setlength\chapterline{30mm}

\pagenumbering{arabic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PAGE STYLE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the first page
% define series title
\newcommand{\seriestitle}[1]{\gdef\@seriestitle{#1}}
% define main title
\newcommand{\maintitle}[1]{\gdef\@maintitle{#1}}
% year on the first page
\newcommand{\setyear}[1]{\gdef\@year{#1}}

% default values
\maintitle{Advanced Systems for Automation and Diagnostics}
\seriestitle{Edited by Z.~Kowalczuk}
\setyear{2015}

% define vertical line thickness
\newcommand{\HRule}{\rule{\linewidth}{0.25mm}}
\newcommand{\HRuleBold}{\rule{\linewidth}{0.75mm}}

% first page layout
\def\ps@firstpage{%
\renewcommand{\@oddhead}{\vtop{\hb@xt@\textwidth{{\fontsize{11}{40}\selectfont \sc\mbox{\@maintitle} \hfil}}\vskip2pt\HRule\vskip+2.4pt  \begin{small}{\@seriestitle,\hskip+3pt \@year \hfill PWNT\hskip+5pt Gda\'{n}sk}\end{small}}}
\renewcommand{\@oddfoot}{}
}

% add parameter to title and author --- short verisons of the title and author
% used in the page head
\renewcommand{\title}[2][]{
 \def\@temp{#1}
 \gdef\@title{#2}
 \ifx\@temp\@empty 
   \gdef\head@title{#2}
 \else
   \gdef\head@title{#1}
 \fi 
}

\renewcommand{\author}[2][]{
 \def\@temp{#1}
 \gdef\@author{#2}
 \ifx\@temp\@empty 
   \gdef\head@author{#2}
 \else
   \gdef\head@author{#1}
 \fi 
}

\newcommand{\address}[1]{
 \gdef\@address{#1}
}

% headers
\def\ps@plain{
 \let\@mkboth\markboth
 \def\@oddhead{}
 \def\@evenhead{}
 \def\@oddfoot{}
 \def\@evenfoot{}
}

\renewcommand{\sectionmark}[1]{\markright{\ifnum \c@secnumdepth >\z@
       \thesection.\,
    \fi
    #1}{}}

\def\ps@pwnt{
 \let\@mkboth\markboth
 \let\@oddfoot\@empty
 \let\@evenfoot\@empty
 \ifthenelse{\boolean{@procstyle}}
 {
   \def\@oddhead{\vtop{\hb@xt@\textwidth{{\hfil \footnotesize \mbox{\head@title} \hfil}\thepage}\vskip2pt\HRule\vskip-2.4pt\vskip+200pt}}
 }
 {
   \def\@oddhead{\vtop{\hb@xt@\textwidth{{\hfil \footnotesize \mbox{\thechapter.\, \head@title} \hfil}\thepage}\vskip2pt\HRule\vskip-2.4pt\vskip+200pt}}
 }
 \def\@evenhead{\vtop{\hb@xt@\textwidth{\thepage \footnotesize \hfil{\head@author} \hfil}\vskip2pt\HRule\vskip-2.4pt\vskip+200pt}}
}

\def\ps@pwntbook{
 \let\@mkboth\markboth
 \let\@oddfoot\@empty
 \let\@evenfoot\@empty
 \def\@oddhead{\vtop{\hb@xt@\textwidth{{\footnotesize \mbox{\rightmark} \hfil}\thepage}\vskip2pt\HRule\vskip-2.4pt\vskip+200pt}}
 \def\@evenhead{\vtop{\hb@xt@\textwidth{\thepage{\hfill \footnotesize \mbox{\thechapter.\, \head@title}}}\vskip2pt\HRule\vskip-2.4pt\vskip+200pt}}
}

\ifthenelse{\boolean{@bookstyle}}
{%
  \pagestyle{pwntbook}
}
{%
  \pagestyle{pwnt}
}

\ifthenelse{\boolean{@bookstyle}}
{%
%%%%%%%%%%%%%%%%%%%%%% BOOK TITLE PAGE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand\maketitle{\newpage\thispagestyle{empty}
  \begingroup
    \noindent\begin{minipage}{\titlewidth}
    \vspace{20mm}
    \begin{flushright}
       {\fontsize{48}{40}\selectfont \bf \thechapter}
    \end{flushright}
       \noindent\HRuleBold 
       \vspace{5mm}
    \begin{flushright}
       \fontsize{18}{20}\selectfont \bf \@title  \\
    \end{flushright}
    \vspace{38mm}
    \end{minipage}
  \endgroup
}
}
{%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% TITLE PAGE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand\maketitle{\newpage\thispagestyle{firstpage}
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \noindent\begin{minipage}{\titlewidth}
        \let\footnotesize\small
        \let\footnoterule\relax
        \let \footnote \thanks
	\ifthenelse{\boolean{@procstyle}}
	{
	  \vspace{50mm}
	}
	{
          \vspace{10mm} 

          \rule{\chapterline}{0.35mm} \\
          {\fontsize{14}{40}\selectfont \bf CHAPTER \thechapter}\\[-3.5mm]
          \rule{\chapterline}{0.35mm}
          \vspace{26mm}
	}

	\begin{center}
	\fontsize{16}{20}\selectfont \bf \@title 
	\end{center}

	\vspace{2mm}

	\begin{center}
%	    {\fontsize{13}{40}\selectfont\bf \@author}
	    {\fontsize{12}{40}\selectfont\bf \@author}
	\end{center}

        \vspace{8mm}

    \end{minipage}
    \@thanks
  \endgroup
    \setcounter{footnote}{0}
}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SECTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%\@startsection{name}{level}{indent}{beforeskip}{afterskip}{style} 

\ifthenelse{\boolean{@procstyle}}
{
  \setcounter{secnumdepth}{2}
  \renewcommand\thesection{\@arabic\c@section}
}
{
  \renewcommand\thesection{\thechapter.\@arabic\c@section}
}
\renewcommand\thesubsection{\thesection.\@arabic\c@subsection}

\renewcommand\@seccntformat[1]{\csname the#1\endcsname.\hspace{0.5em}}
 
\renewcommand\section{ \@startsection{section}{1}{\z@}%
                          {-0.25ex\@plus -1ex \@minus -.2ex}%
                          {+1.0em \@plus .2ex }%
                          {\fontsize{13}{40}\selectfont \bf }}

\renewcommand\subsection{ \@startsection{subsection}{2}{\z@}%
                          {-1.25ex\@plus -1ex \@minus -.2ex}%
                          {+0.5em \@plus .2ex}%
                          {\bf }}

\renewcommand\subsubsection{ \@startsection{subsubsection}{3}{\z@}%
                          {-3.25ex\@plus -1ex \@minus -.2ex}%
                          {-0.5em \@plus .2ex}%
                          {\bf }}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% FIG AND TAB %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\fnum@figure{Fig.~\thefigure}
\def\fnum@table{Tab.~\thetable}

\newlength{\captionindent}
\long\def\@makecaption#1#2#3{
    \vskip 5pt
    \setbox\@tempboxa\hbox{#1.~#2}
    \ifdim \wd\@tempboxa >\hsize
       \setbox\@tempboxa\hbox{#1.~}
       \setlength\captionindent{\wd\@tempboxa} \divide\captionindent by 2
       \addtolength{\hsize}{-\wd\@tempboxa}%
       \mbox{#1.~}\parbox[t]{\hsize}{#2}
       \vskip 8pt
    \else
      \begin{center}
          \textrm{#1.~#2}
      \end{center}
    \fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%% BIBLIOGRAPHY %%%%%%%%%%%%%%%%%%%%%%%%
\ifthenelse{\boolean{@procstyle}}
{
  \newcommand\bibname{References}
}
{
  \newcommand\refname{References}
}
\newdimen\bibindent
\setlength\bibindent{1.5em}
\newdimen\bibspacing
\setlength\bibspacing\z@
\renewenvironment{thebibliography}[1]{%
      {\vskip1cm{\noindent\large\bf{\bibname}}%
      \@mkboth{\refname}{\refname}}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep 
            \itemsep\z@skip% should this be commented out?
            \parsep0pt% the sep between bib items (important -> standard 6pt)
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy\clubpenalty4000\widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

%%%%%%%%%%%%%%%%%%%%%%%%%% OTHER ENVIRONMENTS %%%%%%%%%%%%%%%%%%%%%%%%
% LIST WITH TIGHT SPACING
\newenvironment{itemizetight}{
\begin{itemize}
  \setlength{\itemsep}{0pt}
  \setlength{\parskip}{0pt}
  \setlength{\parsep}{0pt}
  \vspace{-6pt}}{\end{itemize}
}

% THEOREM
\ifthenelse{\boolean{@procstyle}}
{
  \newcounter{theorem}
  \setcounter{theorem}{0}
  \renewcommand\thetheorem{\@arabic\c@theorem}
  \newenvironment{theorem}[1 ]{\vskip12pt
    \refstepcounter{theorem}
    \noindent\textbf{Theorem \@arabic\value{theorem}.\hskip6pt #1 } \it
  }
}
{
  \newcounter{theorem}[chapter]
  \setcounter{theorem}{0}
  \renewcommand\thetheorem{\thechapter.\@arabic\c@theorem}
  \newenvironment{theorem}[1 ]{\vskip12pt
    \refstepcounter{theorem}
    \noindent\textbf{Theorem \thechapter.\@arabic\value{theorem}.\hskip6pt #1 } \it
  }
}
{ 
} 

% DEF
\ifthenelse{\boolean{@procstyle}}
{
  \newcounter{definition}
  \setcounter{definition}{0}
  \renewcommand\thedefinition{\@arabic\c@theorem}
  \newenvironment{definition}[1 ]{\vskip12pt
    \refstepcounter{definition}
    \noindent\textbf{Definition \@arabic\value{definition}.\hskip6pt #1 } \it
  }
}
{
  \newcounter{definition}[chapter]
  \setcounter{definition}{0}
  \renewcommand\thedefinition{\thechapter.\@arabic\c@theorem}
  \newenvironment{definition}[1 ]{\vskip12pt
    \refstepcounter{definition}
    \noindent\textbf{Definition \thechapter.\@arabic\value{definition}.\hskip6pt #1 } \it
  }
}
{ 
} 
% PROOF
\newenvironment{proof}[0]{\vskip12pt\noindent\textit{Proof.} }{\hfill $\square$}

% PROCEDURE
\ifthenelse{\boolean{@procstyle}}
{
  \newcounter{procedure}
  \setcounter{procedure}{0}
  \renewcommand\theprocedure{\@arabic\c@procedure}

  \newenvironment{procedure}[1 ]{\vskip12pt
     \refstepcounter{procedure}
     \noindent\textbf{Procedure \@arabic\value{procedure}.\hskip6pt #1} \small \sf \vspace{-6pt}
  }
}
{
  \newcounter{procedure}[chapter]
  \setcounter{procedure}{0}
  \renewcommand\theprocedure{\thechapter.\@arabic\c@procedure}

  \newenvironment{procedure}[1 ]{\vskip12pt
     \refstepcounter{procedure}
     \noindent\textbf{Procedure \thechapter.\@arabic\value{procedure}.\hskip6pt #1} \small \sf \vspace{-6pt}
  }
}
{ 
} 

% SUMMARY DATA
\newcommand{\summaryauthorspl}[1]{
 \gdef\@summaryauthorspl{#1}
}
\newcommand{\summaryauthorsen}[1]{
 \gdef\@summaryauthorsen{#1}
}
\newcommand{\summarytitlepl}[1]{
 \gdef\@summarytitlepl{#1}
}
\newcommand{\summaryorgpl}[3]{
 \gdef\@summaryorgpla{#1}
 \gdef\@summaryorgplb{#2}
 \gdef\@summaryorgplc{#3}
}
\newcommand{\summarytitleen}[1]{
 \gdef\@summarytitleen{#1}
}
\newcommand{\summaryorgen}[3]{
 \gdef\@summaryorgena{#1}
 \gdef\@summaryorgenb{#2}
 \gdef\@summaryorgenc{#3}
}

\newcommand{\makesummarypl}[1]{
  \begin{center}
    \textbf{\@summarytitlepl} \vspace{16pt} \\
    \textbf{\@summaryauthorspl} \vspace{16pt} \\
    \@summaryorgpla \vspace{4pt}
    \ifx\@summaryorgplb\@empty 
    \else
       \vspace{4pt} \\
       \@summaryorgplb
       \ifx\@summaryorgplc\@empty 
       \else
          \vspace{4pt} \\
          \@summaryorgplc
       \fi 
    \fi 
  \end{center}
  \ifthenelse{\boolean{@procstyle}}
  {
    \textbf{\@summarytitlepl. } 
  }
  {
    \textbf{Rozdzia\l{} #1. \@summarytitlepl. }
  }
}
\newcommand{\makesummaryen}[1]{
  \begin{center}
    \textbf{\@summarytitleen} \vspace{16pt} \\
    \textbf{\@summaryauthorsen} \vspace{16pt} \\
    \@summaryorgena \vspace{4pt}
    \ifx\@summaryorgenb\@empty 
    \else
       \vspace{4pt} \\
       \@summaryorgenb
       \ifx\@summaryorgenc\@empty 
       \else
          \vspace{4pt} \\
          \@summaryorgenc
       \fi 
    \fi 
  \end{center}
  \ifthenelse{\boolean{@procstyle}}
  {
    \textbf{\@summarytitleen. } 
  }
  {
    \textbf{Chapter #1. \@summarytitleen. }
  }
}
% APPENDIX
\newcounter{appendixc}
\renewcommand{\appendix}[1] {\vspace*{0.6cm}
	\refstepcounter{appendixc}
	\setcounter{section}{\theappendixc}%
	\setcounter{subsection}{0}%
	\renewcommand\thesection{\@arabic\c@section}
	\@mkboth{Supplement \thesection.\, #1}{Supplement \thesection.\, #1}
        \noindent{\fontsize{13}{40}\selectfont\bf Supplement \thesection.\hskip6pt#1}\vspace*{0.4cm}\\}
